@@ -50,6 +50,14 @@ from simmate.calculators.vasp.database.dynamics import (
     MITDynamicsIonicStep,
 )
 
+from simmate.calculators.vasp.database.population_analysis import (
+    MatProjBaderAnalysis,
+)
+
+from simmate.calculators.vasp.database.customized import (
+    CustomizedVASPCalculation,
+)
+
 # This module is still under early development
 # from simmate.toolkit.structure_prediction.evolution.database import (
 #     EvolutionarySearch,
